# 使用 Restito 工具进行 REST 客户端测试

> 原文： [https://www.guru99.com/rest-client-testing.html](https://www.guru99.com/rest-client-testing.html)

## 什么是 REST？

**REST** 代表“代表状态转移”，这是在给定时间点任何两个系统之间进行通信的新方式。 其中一个系统称为“ REST 客户端”，另一个系统称为“ REST 服务器”。

在此 REST 教程中，您将学习：

*   [什么是 REST？](#1)
*   [什么是 REST 客户端？](#2)
*   [什么是 REST Server？](#3)
*   [什么是 Restito？](#4)
*   [如何使用 Restito 测试 REST 客户端？](#5)
*   [使用 Restito Framework 进行 REST 客户端测试的优势](#6)
*   [使用 Restito Framework 进行 REST 客户端测试的缺点](#7)

在了解用于 REST 客户端测试的 Restito Framework 之前，让我们首先学习一些基础知识。

## 什么是 REST 客户端？

REST 客户端是一种调用 REST 服务 API 的方法或工具，该 API 公开供任何系统或服务提供商进行通信。 例如：如果公开一个 API 来获取来自 Google 的路线的实时路况信息，则调用 Google 流量 API 的软件/工具称为 REST 客户端。

## 什么是 REST Server？

它是任何系统或服务提供商都可以进行通信的方法或 API。 例如，Google 公开了一个 API，以获取给定路线上的实时路况信息。

在这里，Google 服务器需要启动并运行，以侦听来自不同客户端的对公开 API 的任何请求。

### 例：

现在该根据上述定义建立一个完整的端到端方案。

让我们考虑像 Uber 这样的出租车预订应用程序，因为公司需要有关给定车辆所在路线周围交通状况的实时信息。

### 休息客户：

客户端是驱动程序已登录的 Uber 移动应用程序。 该应用向 Google 地图公开的 REST API 发送请求，以获取实时数据。 例如，一个 HTTP GET 请求。

### 休息服务器：

在此示例中，Google 是服务提供商，并且 Google Maps 的 API 会以所需的详细信息响应 Uber 应用程序的请求。

客户端和服务器在 REST 通信中同等重要。

在这里，我们实现了仅用于 REST 客户端的自动化测试的示例。 要测试 REST 服务器，请参阅 [https://www.guru99.com/top-6-api-testing-tool.html](https://www.guru99.com/top-6-api-testing-tool.html) 。

## 什么是 Restito？

Restito 是 Mkotsur 开发的框架。 这是一个轻量级的应用程序，可以帮助您执行任何类型的 HTTP 请求。 您可以使用 Restito 测试 REST API 并搜索应用程序或网络中的问题。

## 如何使用 Restito 测试 REST 客户端？

让我们将练习分为以下四个步骤：

1.  创建一个 HTTP 客户端和方法以将 HTTP GET 请求发送到任何服务器端点。 现在，将端点视为 [http：// localhost：9092 / getevents。](http://localhost:9092/getevents)

2.  启动 Restito 服务器以侦听并捕获发送到 localhost [http：// localhost：9092 / getevents](http://localhost:9092/getevents) 中的端点“ getevents”的请求。

3.  创建一个测试类来测试上述客户端。 调用 HTTP 客户端的“ sendGETRequest”方法以向 API“ getevents”发起 GET 请求。

4.  使用 Restito 框架验证 HTTP GET 调用。

让我们深入研究上述每个步骤。

**步骤 1）**创建一个 HTTP 客户端和方法，以将 HTTP GET 请求发送到任何服务器端点。

========== Java 代码开始===========

```
package com.chamlabs.restfulservices.client;

import java.util.HashMap;
import java.util.Map;

import org.apache.http.client.HttpClient;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.entity.StringEntity;
import org.apache.http.impl.client.HttpClientBuilder;
import org.json.JSONObject;

/**
 * This class creates a HTTP Client and has a method to send HTTP GET request: 
 * 		sendGETRequest(..)
 */
public class RestClient {
	/**
	 * Constructor for the  class RestClient	
	 */
	public RestClient() {
		System.out.println("Creating RestClient constructor");
	}

	/**
	 * Method to Send GET request to http://localhost:<<port>>/getevents
	 * @param port
	 * @return true if GET request is successfully sent. False, otherwise.
	 */
	public static boolean sendGETRequest(int port) {
		try {
			HttpClient client = HttpClientBuilder.create().build();
			HttpGet getRequest = new HttpGet("http://localhost:" + port + "/getevents");
			//HttpResponse response = client.execute(request);
			client.execute(getRequest);
			System.out.println("HTTP request is sent successfully."
					+ "Returning True");
			return true;
		} 

		catch (Exception e) {
			e.printStackTrace();
		}
		System.out.println("Some exception has occurred during the HTTP Client creation."
				+ "Returning false");
		return false;
	}
}

```

========== JAVA CODE Ends ===========

**步骤 2）**启动 Restito 服务器以侦听并捕获发送到本地主机 [http：// localhost：9092 / getevents](http://localhost:9092/getevents) 中的端点“ getevents”的请求。

========== JAVA CODE Starts ===========

```
package com.chamlabs.restfultesting.util;

import static com.xebialabs.restito.builder.stub.StubHttp.whenHttp;
import static com.xebialabs.restito.semantics.Action.status;
import static com.xebialabs.restito.semantics.Condition.get;
import static com.xebialabs.restito.semantics.Condition.post;
import java.util.List;
import org.glassfish.grizzly.http.util.HttpStatus;
import com.xebialabs.restito.semantics.Call;
import com.xebialabs.restito.server.StubServer;

/**
 * This utility class contains several utility methods like : 
 * 		restartRestitoServerForGETRequests(..)
 * 		restartRestitoServerForPOSTRequests(..) 
 * 		waitAndGetCallList(..)
 * 
 * @author cham6
 * @email: paperplanes.chandra@gmail.com
 * @fork: https://github.com/cham6/restfultesting.git
 *
 */
public class TestUtil {

	/**
	 * Utility method to start restito stub server to accept GET requests
	 * @param server
	 * @param port
	 * @param status
	 */
	public static void restartRestitoServerForGETRequests (StubServer server, int port, HttpStatus status)
    {
        // Kill the restito server
        if (server != null) {
            server.stop();
        }
        // Initialize and configure a newer instance of the stub server
        server = new StubServer(port).run();
        whenHttp(server).match(get("/getevents")).then(status(status));
    }

	/**
	 * Utility method to start restito stub server to accept POST requests
	 * @param server
	 * @param port
	 * @param status
	 */
	public static void restartRestitoServerForPOSTRequests (StubServer server, int port, HttpStatus status)
    {
        // Kill the restito server
        if (server != null) {
            server.stop();
        }
        // Initialize and configure a newer instance of the stub server
        server = new StubServer(port).run();
        whenHttp(server).match(post("/postevents")).then(status(status));
    }

	/**
     * For a given restito stub server, loop for the given amount of seconds and
     * break and return the call list from server.
     * 
     * @param server
     * @param waitTimeInSeconds
     * @return
     * @throws InterruptedException
     */
	public static List<Call> waitAndGetCallList (StubServer server, int waitTimeInSeconds)
        throws InterruptedException
    {
        int timeoutCount = 0;
        List<Call> callList = server.getCalls();
        while (callList.isEmpty()) {
            Thread.sleep(1000);
            timeoutCount++;
            if (timeoutCount >= waitTimeInSeconds) {
                break;
            }
            callList = server.getCalls();
        }
        // Wait for 2 seconds to get all the calls into callList to Eliminate any falkyness.
        Thread.sleep(2000);
        return server.getCalls();
    }

}

```

========== JAVA CODE Ends ===========

**步骤 3）**创建一个测试类来测试上述客户端。 调用 HTTP 客户端的 sendGETRequest 方法，以启动对 API“ getevents”的 GET 请求。

========== JAVA CODE Starts ===========

```
import junit.framework.TestCase;

import com.chamlabs.restfulservices.client.RestClient;
import com.chamlabs.restfultesting.util.TestUtil;
import com.xebialabs.restito.semantics.Call;
import com.xebialabs.restito.server.StubServer;
import static org.glassfish.grizzly.http.util.HttpStatus.ACCEPTED_202;
import org.json.JSONObject;
import java.util.List;
import java.util.Map;

/**
 * This class contains several junit tests to validate the RestClient operations like: 
 * 		sendRequest(..)
 * 		sendRequestWithCustomHeaders(..) 
 * 		sendPOSTRequestWithJSONBody(..)
 *
 */

public class RestClientTester extends TestCase {

    private static final Integer PORT = 9098;
    private static final Integer PORT2 = 9099;
    private static final Integer PORT3 = 9097;

    public RestClientTester() {
    	System.out.println("Starting the test RestClientTester");
    }
    /**
     * Junit test to validate the GET request from RestClient
     * Steps:
     * 		1) Create a stub server using Restito framework and configure it to listen on given port
     * 		2) Invoke the sendGETRequest(..) method of RestClient
     * 		3) Restito captures the matching GET requests sent, if any.
     * 		4) Validate if Restito has captured any GET requests on given endpoint
     * Expected Behavior:
     * 		> Restito should have captured GET request and it should have captured only one GET request.
     * Finally:
     * 		> Stop the stub server started using restito.
     */
	public void testGETRequestFromClient() {

		StubServer server = null;
		try {
		//This will start the stub server on 'PORT' and responds with HTTP 202 'ACCEPTED_202'
		TestUtil.restartRestitoServerForGETRequests(server, PORT, ACCEPTED_202);

		RestClient.sendGETRequest(PORT);

		List<Call> callList = TestUtil.waitAndGetCallList(server, 30);
		assertTrue("GET request is not received from the RestClient. Test failed.", 
				(callList != null) && (callList.size() == 1));
		}
		catch(Exception e) {
			e.printStackTrace();
			fail("Test Failed due to exception : " + e);
		}
		finally {
			if(server != null) {
				server.stop();
            }
		}	
	}

```

========== JAVA CODE Ends ===========

**步骤 4）**如何使用 Restito 框架验证带有标头的 GET 请求和带有正文的 POST 请求。

========== JAVA CODE Starts ===========

```
	/**
     * Junit test to validate the GET request with headers from RestClient
     * Steps:
     * 		1) Create a stub server using Restito framework and configure it to listen on given port
     * 		2) Invoke the sendGETRequestWithCustomHeaders(..) method of RestClient
     * 		3) Restito captures the matching GET requests sent, if any. 
     * 		4) Validate if Restito has captured any GET requests on a given endpoint
     * Expected Behavior:
     * 		> Restito should have captured GET request, and it should have captured only one GET request.
     * 		> Get the headers of the captured GET request 
     * 		  and make sure the headers match to the ones configured.
     * Finally:
     * 		> Stop the stub server started using restito.
     */

public void testGETRequestWithHeadersFromClient() {
		StubServer server = null;

		try {
		//This will start the stub server on 'PORT' and responds with HTTP 202 'ACCEPTED_202'
			TestUtil.restartRestitoServerForGETRequests(server, PORT2, ACCEPTED_202);

		RestClient.sendGETRequestWithCustomHeaders(PORT2);

		List<Call> callList = TestUtil.waitAndGetCallList(server, 30);
		assertTrue("GET request is not received from the RestClient. Test failed.", 
				(callList != null) && (callList.size() == 1));

		//Validate the headers of the GET request from REST Client
		Map<String, List<String>> headersFromRequest = callList.get(0).getHeaders();
		assertTrue("GET request contains header Accept and its value ",
				headersFromRequest.get("Accept").contains("text/html"));
		assertTrue("GET request contains header Authorization and its value ",
				headersFromRequest.get("Authorization").contains("Bearer 1234567890qwertyuiop"));
		assertTrue("GET request contains header Cache-Control and its value ",
				headersFromRequest.get("Cache-Control").contains("no-cache"));
		assertTrue("GET request contains header Connection and its value ",
				headersFromRequest.get("Connection").contains("keep-alive"));
		assertTrue("GET request contains header Content-Type and its value ",
				headersFromRequest.get("Content-Type").contains("application/json"));
		}
		catch(Exception e) {
			e.printStackTrace();
			fail("Test Failed due to exception : " + e);
		}
		finally {
			if(server != null) {
				server.stop();
            }
		}
	}

```

```
/**
     * Junit test to validate the POST request with body and headers from RestClient
     * Steps:
     * 		1) Create a stub server using Restito framework and configure it to listen on given port
     * 		2) Invoke the sendPOSTRequestWithJSONBody(..) method of RestClient
     * 		3) Restito captures the matching POST requests sent, if any.
     * 		4) Validate if Restito has captured any POST requests on given endpoint
     * Expected Behavior:
     * 		> Restito should have captured POST request and it should have captured only one POST request.
     * 		> Get the body of the captured POST request and validate the JSON values
     * Finally:
     * 		> Stop the stub server started using restito.
	 */

public void testPOSTRequestWithJSONBody() {
		StubServer server = null;

		try {
		//This will start the stub server on 'PORT' and responds with HTTP 202 'ACCEPTED_202'
			TestUtil.restartRestitoServerForPOSTRequests(server, PORT3, ACCEPTED_202);

		RestClient.sendPOSTRequestWithJSONBody(PORT3);

		List<Call> callList = TestUtil.waitAndGetCallList(server, 30);
		assertTrue("POST request is not received from the RestClient. Test failed.", 
				(callList != null) && (callList.size() == 1));

		//Validate the headers of the GET request from REST Client

		String requestBody = callList.get(0).getPostBody();
		JSONObject postRequestJSON = new JSONObject(requestBody);
		assertTrue("The timeUpdated in json is incorrect",
				postRequestJSON.get("timeUpdated").toString().equalsIgnoreCase("1535703838478"));
		assertTrue("The access_token in json is incorrect",
				postRequestJSON.get("access_token").toString().
				equalsIgnoreCase("abf8714d-73a3-42ab-9df8-d13fcb92a1d8"));
		assertTrue("The refresh_token in json is incorrect",
				postRequestJSON.get("refresh_token").toString().
				equalsIgnoreCase("d5a5ab08-c200-421d-ad46-2e89c2f566f5"));
		assertTrue("The token_type in json is incorrect",
				postRequestJSON.get("token_type").toString().equalsIgnoreCase("bearer"));
		assertTrue("The expires_in in json is incorrect",
				postRequestJSON.get("expires_in").toString().equalsIgnoreCase("1024"));
		assertTrue("The scope in json is incorrect",
				postRequestJSON.get("scope").toString().equalsIgnoreCase(""));
		}
		catch(Exception e) {
			e.printStackTrace();
			fail("Test Failed due to exception : " + e);
		}
		finally {
			if(server != null) {
				server.stop();
            }
		}
	}
}

```

========== JAVA CODE Ends ===========

## 使用 Restito Framework 进行 REST 客户端测试的优势

这是用于 ReST 客户端测试的 Restito Framework 的优点/优点

*   我们不需要开发实际的 REST 服务器来测试 REST 客户端。
*   Restito 提供了强大而多样的实用程序和方法来模拟服务器的不同行为。 例如：测试服务器响应 HTTP 404 错误或 HTTP 503 错误时 REST 客户端的行为。
*   Restito 服务器可以在几毫秒内完成设置，并且可以在测试完成后终止。
*   Restito 支持所有类型的 HTTP 方法内容，例如压缩，非压缩，统一，应用程序/文本，应用程序/ JSON 等。

## 使用 Restito Framework 进行 REST 客户端测试的缺点

这是用于 ReST 客户端测试的 Restito Framework 的缺点/缺点

*   应当调整 REST 客户端源，以将“ localhost”视为服务器计算机。
*   如果我们使用一些常用端口（例如“ 8080”或“ 9443”等），则在任何端口打开服务器都可能会发生冲突。
*   建议使用其他工具不常用的端口，例如 9092 或 9099。

### 摘要：

*   REST 代表“代表状态转移”，这是在给定时间点任何两个系统之间进行通信的新标准方式。
*   REST 客户端是一种调用 REST 服务 API 的方法或工具，该 API 公开给任何系统或服务提供商进行通信。
*   在 RestServer 方法中或公开供任何系统或服务提供者进行通信的 API 中。
*   Restito 是一款轻巧的应用程序，可帮助您执行任何类型的 HTTP 请求
*   创建一个 HTTP 客户端和方法以将 HTTP GET 请求发送到任何服务器端点
*   启动 Restito 服务器以侦听和捕获发送到端点“ getevents”的请求。
*   启动 Restito 服务器以侦听和捕获发送到 localhost 中的端点“ getevents”的请求
*   在这里，我们实现了仅用于 REST 客户端的自动化测试的示例。
*   我们不需要开发实际的 REST 服务器来测试 REST 客户端。
*   应当调整 REST 客户端源，以将“ localhost”视为服务器计算机。

本文由 Chandrasekhar Muttineni 提供