# 什么是本地化测试？ 测试用例示例&清单

> 原文： [https://www.guru99.com/localization-testing.html](https://www.guru99.com/localization-testing.html)

## 什么是本地化测试？

**本地化测试**是一种软件测试技术，用于检查软件是否根据本地区域性或设置运行。 进行本地化测试的目的是检查特定语言环境的适当语言和文化方面。 换句话说，这是根据目标语言和国家/地区定制软件应用程序的过程。

受本地化测试影响的主要领域包括**内容和 UI。**

这是测试全球化应用程序的过程，该全球化应用程序的 UI，默认语言，货币，日期，时间格式和文档均根据目标国家或地区进行设计。 它确保该应用程序有足够的能力在该特定国家/地区使用。

**示例：**

1.如果该项目是为印度的泰米尔纳德邦设计的，则设计的项目应使用泰米尔语，并应使用泰米尔虚拟键盘等。

2.如果项目是为美国设计的，则应根据美国标准时间更改时间格式。 此外，语言和货币格式应遵循美国标准。

<center>![Localization Testing Tutorial: Learn with Sample Test Cases](img/908956f8be13c1d0d7eb02b66a40612b.png)</center>

### 为什么要进行本地化测试？

进行本地化测试的目的是检查特定语言环境的适当语言和文化方面。 它包括根据要求更改用户界面，甚至更改初始设置。

在这种类型的测试中，许多不同的测试人员将重复相同的功能。 他们会验证各种内容，例如印刷错误，UI 的文化适用性，语言错误等。

它也被称为“ **L10N** ”，因为单词本地化在 L & N 之间有 10 个字符。

## 如何进行本地化测试

对于典型的本地化测试，我们设置了构建验证测试，[功能测试](/functional-testing.html)，[回归测试](/regression-testing.html)以及最终签核。

1.构建验证测试是功能测试的一小部分，它是在质量检查开始进行任何详细测试之前执行的。

2.正常测试是运行正常测试用例并在执行过程中查找日志缺陷的步骤。

3.回归测试是[缺陷](/defect-management-process.html)回归过程，以确保缺陷已修复，而固定缺陷对周围区域没有影响。

4.最终签核是在交付给客户之前对构建进行最终检查。

## 本地化测试自动化

如果项目很大并且需要经常测试，那么我们就去[自动化测试](/automation-testing.html)。

*   选择自动化工具来编写脚本。

*   以要测试的方案进行本地化策略。

*   根据该脚本编写脚本。

*   收集结果并将方案更新为“通过/失败”。

**注意**：[硒](/selenium-tutorial.html)是该领域的先驱工具之一。 它功能非常丰富，但是需要更多的技术知识才能使用。

## 本地化测试的最佳做法清单

*   雇用一家在 **i18n** 工程方面具有专业知识的本地化公司
*   确保您的本地化测试策略为双字节语言留出更多时间。
*   在提取任何文本进行翻译之前，请确保您已正确国际化了 DBCS 的代码

在本教程中查看[本地化测试和全球化测试之间的区别。](/globalization-vs-localization-testing.html)

## 本地化测试的示例测试用例

| S.No | 测试用例描述 |
| 1 | 词汇表可供参考和检查。 |
| 2 | 目标区域的时间和日期格式正确。 |
| 3 | 电话号码格式适合目标区域。 |
| 4 | 目标区域的货币。 |
| 5 | 许可和规则是否遵循当前的网站（地区）。 |
| 6 | 页面中的文本内容布局无错误，字体独立且行对齐。 |
| 7 | 特殊字符，超链接和热键功能。 |
| 8 | 输入字段的验证消息。 |
| 9 | 生成的内部版本包括所有必需的文件。 |
| 10 | 本地化的屏幕具有与源产品相同的元素和数字类型。 |
| 11 | 确保软件或 Web 应用程序的本地化用户界面与目标操作系统和用户环境中的源用户界面比较。 |

## 本地化测试的优势

以下是本地化测试的好处

*   整体测试成本降低
*   总体支持成本降低
*   帮助减少测试时间。
*   它具有更多的灵活性和可伸缩性。

## 本地化测试的缺点

以下是本地化测试的挑战

*   需要领域专家
*   雇用本地翻译人员通常会使流程昂贵
*   不同国家/地区 DBCS 字符的存储方式有所不同
*   测试人员可能会面临进度挑战

**摘要：**

*   在软件工程中，进行了本地化测试以确保产品的行为符合本地文化或设置
*   受本地化测试影响的主要领域包括内容和 UI。
*   测试人员会验证各种错误，例如印刷错误，UI 的文化适用性，语言错误等。

***本文由 Deepan Fernandez 提供***